document.addEventListener('DOMContentLoaded', () => {
    const addScoreBtn = document.getElementById('addScoreBtn');
    const modal = document.getElementById('addScoreModal');
    const cancelBtn = document.getElementById('cancelBtn');
    const searchInput = document.getElementById('searchInput');
    const scoreForm = document.getElementById('scoreForm');
    const autoPopulateBtn = document.getElementById('autoPopulateBtn');
    const exportBtn = document.getElementById('exportBtn');

    // Sample data structure
    let competitions = [];

    // Show modal
    addScoreBtn.addEventListener('click', () => {
        modal.style.display = 'flex';
    });

    // Hide modal
    cancelBtn.addEventListener('click', () => {
        modal.style.display = 'none';
        scoreForm.reset();
    });

    // Close modal when clicking outside
    modal.addEventListener('click', (e) => {
        if (e.target === modal) {
            modal.style.display = 'none';
            scoreForm.reset();
        }
    });

    // Handle form submission
    scoreForm.addEventListener('submit', (e) => {
        e.preventDefault();
        // Add form data handling here
        modal.style.display = 'none';
        scoreForm.reset();
        updateTable();
    });

    // Search functionality
    searchInput.addEventListener('input', () => {
        updateTable();
    });

    // Auto-populate button click handler
    autoPopulateBtn.addEventListener('click', async () => {
        const url = document.getElementById('competitionUrl').value;
        const lastName = document.getElementById('lastName').value;
        
        try {
            // Add URL fetching and auto-population logic here
            console.log('Auto-populating fields...');
        } catch (error) {
            console.error('Error auto-populating fields:', error);
        }
    });

    // Export data
    exportBtn.addEventListener('click', () => {
        const exportData = JSON.stringify(competitions, null, 2);
        const blob = new Blob([exportData], { type: 'application/json' });
        const url = URL.createObjectURL(blob);
        const a = document.createElement('a');
        a.href = url;
        a.download = 'skating-scores.json';
        document.body.appendChild(a);
        a.click();
        document.body.removeChild(a);
        URL.revokeObjectURL(url);
    });

    function updateTable() {
        const searchTerm = searchInput.value.toLowerCase();
        const filteredData = competitions.filter(comp => 
            comp.name.toLowerCase().includes(searchTerm)
        );
        
        const tbody = document.querySelector('#competitionTable tbody');
        tbody.innerHTML = '';
        
        filteredData.forEach(comp => {
            const row = document.createElement('tr');
            row.innerHTML = `
                <td>${comp.name}</td>
                <td>${comp.date}</td>
                <td>${comp.place}</td>
                <td>${comp.competitors}</td>
                <td>${comp.score}</td>
                <td>
                    <button class="secondary-btn">View Details</button>
                    <button class="secondary-btn">Delete</button>
                </td>
            `;
            tbody.appendChild(row);
        });
    }

    // Initial table update
    updateTable();
});